@@ -2,10 +2,7 @@ package Dist::Zilla::PluginBundle::AVAR;
 BEGIN {
   $Dist::Zilla::PluginBundle::AVAR::AUTHORITY = 'cpan:AVAR';
 }
-{
-  $Dist::Zilla::PluginBundle::AVAR::VERSION = '0.30';
-}
-
+$Dist::Zilla::PluginBundle::AVAR::VERSION = '0.31';
 use 5.10.0;
 use Moose;
 use Moose::Autobox;
@@ -184,6 +181,18 @@ sub bundle_config {
         },
     });
 
+    # remove empty entries, Config::MVP crashes on them
+
+    foreach my $p (@plugins) {
+        my ($name, $package, $payload) = @$p;
+
+        while (my ($k, $v) = each %$payload) {
+            if (!$v || (ref $v eq 'ARRAY' && !@$v) || (ref $v eq 'HASH' && !%$v)) {
+                delete $payload->{$k};
+            }
+        }
+    }
+
     return @plugins;
 }
 
